==> jc-1.4.0.tar.gz: gnu/java/nio/ChannelReader.h <==
// public class gnu.java.nio.ChannelReader

// class file dependencies
// @dep_class f7333d027d9f90b1 gnu_java_nio_ChannelReader
// @dep_class 688afb20bd4c4e01 java_io_Reader
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_Reader

#include "java/io/Reader.h"

#ifndef _JC_gnu_java_nio_ChannelReader_H_
#define _JC_gnu_java_nio_ChannelReader_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_ByteBuffer$object;
struct _jc_java_nio_CharBuffer$object;
struct _jc_java_nio_channels_ReadableByteChannel$object;
struct _jc_java_nio_charset_CharsetDecoder$object;

// Typedefs
typedef struct _jc_gnu_java_nio_ChannelReader$sub_refs	_jc_gnu_java_nio_ChannelReader$sub_refs;
typedef struct _jc_gnu_java_nio_ChannelReader$sub_nonrefs	_jc_gnu_java_nio_ChannelReader$sub_nonrefs;
typedef struct _jc_gnu_java_nio_ChannelReader$refs	_jc_gnu_java_nio_ChannelReader$refs;
typedef struct _jc_gnu_java_nio_ChannelReader$nonrefs	_jc_gnu_java_nio_ChannelReader$nonrefs;
typedef struct _jc_gnu_java_nio_ChannelReader$object	_jc_gnu_java_nio_ChannelReader$object;

typedef struct _jc_gnu_java_nio_ChannelReader$fields_struct	_jc_gnu_java_nio_ChannelReader$fields_struct;
typedef const struct _jc_gnu_java_nio_ChannelReader$vmethods	_jc_gnu_java_nio_ChannelReader$vmethods;
typedef const struct _jc_gnu_java_nio_ChannelReader$vtable	_jc_gnu_java_nio_ChannelReader$vtable;
typedef const struct _jc_gnu_java_nio_ChannelReader$vtype	_jc_gnu_java_nio_ChannelReader$vtype;

// Class fields structure
struct _jc_gnu_java_nio_ChannelReader$fields_struct {
	jint	DEFAULT__5fBUFFER__5fCAP;
};
extern _jc_gnu_java_nio_ChannelReader$fields_struct _jc_gnu_java_nio_ChannelReader$class_fields;

// Constructors
extern void _jc_gnu_java_nio_ChannelReader$method$_init$d815030b8fb07c7a(_jc_env *, struct _jc_gnu_java_nio_ChannelReader$object *, struct _jc_object *, struct _jc_java_nio_charset_CharsetDecoder$object *, jint);

// Virtual methods
extern void _jc_gnu_java_nio_ChannelReader$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_gnu_java_nio_ChannelReader$object *);
extern jint _jc_gnu_java_nio_ChannelReader$method$read$146ad4b836c4a55b(_jc_env *, struct _jc_gnu_java_nio_ChannelReader$object *, struct _jc_char_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_ChannelReader$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_gnu_java_nio_ChannelReader$method_info$read$146ad4b836c4a55b;

// Virtual methods structure
struct _jc_gnu_java_nio_ChannelReader$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_gnu_java_nio_ChannelReader$object *);
	jint	(*read$146ad4b836c4a55b)(_jc_env *, struct _jc_gnu_java_nio_ChannelReader$object *, struct _jc_char_array *, jint, jint);
};

// Vtable
struct _jc_gnu_java_nio_ChannelReader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_Reader$vmethods	java_io_Reader;
	_jc_gnu_java_nio_ChannelReader$vmethods	gnu_java_nio_ChannelReader;
};

// Vtype
struct _jc_gnu_java_nio_ChannelReader$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_ChannelReader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_ChannelReader$sub_refs {
	struct _jc_object	*channel;
	struct _jc_java_nio_charset_CharsetDecoder$object	*decoder;
	struct _jc_java_nio_ByteBuffer$object	*byteBuffer;
	struct _jc_java_nio_CharBuffer$object	*charBuffer;
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_ChannelReader$refs {
    _jc_gnu_java_nio_ChannelReader$sub_refs	gnu_java_nio_ChannelReader;
    _jc_java_io_Reader$sub_refs	java_io_Reader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_ChannelReader$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_ChannelReader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_Reader$sub_nonrefs	java_io_Reader;
    _jc_gnu_java_nio_ChannelReader$sub_nonrefs	gnu_java_nio_ChannelReader;
};

// Object instance structure
struct _jc_gnu_java_nio_ChannelReader$object {
	_jc_gnu_java_nio_ChannelReader$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_ChannelReader$vtype	*vtype;
	_jc_gnu_java_nio_ChannelReader$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_ChannelReader$vtype _jc_gnu_java_nio_ChannelReader$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_ChannelReader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_ChannelReader$class_object;

#endif	/* _JC_gnu_java_nio_ChannelReader_H_ */

==> jc-1.4.6.tar.gz: gnu/java/nio/ChannelReader.h <==
// public class gnu.java.nio.ChannelReader

// class file dependencies
// @dep_class f7333d027d9f90b1 gnu_java_nio_ChannelReader
// @dep_class 688afb20bd4c4e01 java_io_Reader
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_Reader

#include "java/io/Reader.h"

#ifndef _JC_gnu_java_nio_ChannelReader_H_
#define _JC_gnu_java_nio_ChannelReader_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_ByteBuffer$object;
struct _jc_java_nio_CharBuffer$object;
struct _jc_java_nio_channels_ReadableByteChannel$object;
struct _jc_java_nio_charset_CharsetDecoder$object;

// Typedefs
typedef struct _jc_gnu_java_nio_ChannelReader$sub_refs	_jc_gnu_java_nio_ChannelReader$sub_refs;
typedef struct _jc_gnu_java_nio_ChannelReader$sub_nonrefs	_jc_gnu_java_nio_ChannelReader$sub_nonrefs;
typedef struct _jc_gnu_java_nio_ChannelReader$refs	_jc_gnu_java_nio_ChannelReader$refs;
typedef struct _jc_gnu_java_nio_ChannelReader$nonrefs	_jc_gnu_java_nio_ChannelReader$nonrefs;
typedef struct _jc_gnu_java_nio_ChannelReader$object	_jc_gnu_java_nio_ChannelReader$object;

typedef struct _jc_gnu_java_nio_ChannelReader$fields_struct	_jc_gnu_java_nio_ChannelReader$fields_struct;
typedef const struct _jc_gnu_java_nio_ChannelReader$vmethods	_jc_gnu_java_nio_ChannelReader$vmethods;
typedef const struct _jc_gnu_java_nio_ChannelReader$vtable	_jc_gnu_java_nio_ChannelReader$vtable;
typedef const struct _jc_gnu_java_nio_ChannelReader$vtype	_jc_gnu_java_nio_ChannelReader$vtype;

// Class fields structure
struct _jc_gnu_java_nio_ChannelReader$fields_struct {
	jint	DEFAULT__5fBUFFER__5fCAP;
};
extern _jc_gnu_java_nio_ChannelReader$fields_struct _jc_gnu_java_nio_ChannelReader$class_fields;

// Constructors
extern void _jc_gnu_java_nio_ChannelReader$method$_init$d815030b8fb07c7a(_jc_env *, struct _jc_gnu_java_nio_ChannelReader$object *, struct _jc_object *, struct _jc_java_nio_charset_CharsetDecoder$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_nio_ChannelReader$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_gnu_java_nio_ChannelReader$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_nio_ChannelReader$method$read$146ad4b836c4a55b(_jc_env *, struct _jc_gnu_java_nio_ChannelReader$object *, struct _jc_char_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_ChannelReader$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_gnu_java_nio_ChannelReader$method_info$read$146ad4b836c4a55b;

// Virtual methods structure
struct _jc_gnu_java_nio_ChannelReader$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_gnu_java_nio_ChannelReader$object *) _JC_JCNI_ATTR;
	jint	(*read$146ad4b836c4a55b)(_jc_env *, struct _jc_gnu_java_nio_ChannelReader$object *, struct _jc_char_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_nio_ChannelReader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_Reader$vmethods	java_io_Reader;
	_jc_gnu_java_nio_ChannelReader$vmethods	gnu_java_nio_ChannelReader;
};

// Vtype
struct _jc_gnu_java_nio_ChannelReader$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_ChannelReader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_ChannelReader$sub_refs {
	struct _jc_object	*channel;
	struct _jc_java_nio_charset_CharsetDecoder$object	*decoder;
	struct _jc_java_nio_ByteBuffer$object	*byteBuffer;
	struct _jc_java_nio_CharBuffer$object	*charBuffer;
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_ChannelReader$refs {
    _jc_gnu_java_nio_ChannelReader$sub_refs	gnu_java_nio_ChannelReader;
    _jc_java_io_Reader$sub_refs	java_io_Reader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_ChannelReader$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_ChannelReader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_Reader$sub_nonrefs	java_io_Reader;
    _jc_gnu_java_nio_ChannelReader$sub_nonrefs	gnu_java_nio_ChannelReader;
};

// Object instance structure
struct _jc_gnu_java_nio_ChannelReader$object {
	_jc_gnu_java_nio_ChannelReader$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_ChannelReader$vtype	*vtype;
	_jc_gnu_java_nio_ChannelReader$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_ChannelReader$vtype _jc_gnu_java_nio_ChannelReader$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_ChannelReader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_ChannelReader$class_object;

#endif	/* _JC_gnu_java_nio_ChannelReader_H_ */
